<?php

namespace IPQualityScore\IPQualityScore\Controller\Adminhtml\Index;

use Magento\Backend\App\Action\Context;
use Magento\Framework\View\Result\PageFactory;
use Magento\Framework\App\Config\Storage\WriterInterface;

class IPQSDashboard extends \Magento\Backend\App\Action
{
    protected $resultPageFactory;
    private $scopeConfig;

    public function __construct(
        Context $context,
        PageFactory $resultPageFactory,
        \Magento\Framework\App\Config\Storage\WriterInterface $configWriter,
        \Magento\Framework\App\Config\ScopeConfigInterface $scopeConfig
    ) {
        parent::__construct($context);
        $this->resultPageFactory = $resultPageFactory;
        $this->scopeConfig = $scopeConfig;
        $this->configWriter = $configWriter;
    }

    public function execute()
    {
        try {
            $resultPage = $this->resultPageFactory->create();
            $resultPage->getLayout()->initMessages();
            $isAuthed = $this->scopeConfig->getValue('ipqualityscore/general/auth_token', \Magento\Framework\App\Config\ScopeConfigInterface::SCOPE_TYPE_DEFAULT, 0);
            $integration = new \IpQualityScore\Integration($isAuthed, 'magentov2');
            $overviewGraphs = $integration->getOverviewGraphs();
            if (!$isAuthed) {
                $domain = $_SERVER['HTTP_HOST'];
                $protocol = (isset($_SERVER['HTTPS']) && ($_SERVER['HTTPS'] == 'on')) ? 'https' : 'http';
                $returnUrl = (isset($_SERVER['HTTPS']) && $_SERVER['HTTPS'] === 'on' ? "https" : "http") . "://{$_SERVER['HTTP_HOST']}{$_SERVER['REQUEST_URI']}";
                $mainPath = (isset($_SERVER['HTTPS']) && $_SERVER['HTTPS'] === 'on' ? "https" : "http") . "://{$_SERVER['HTTP_HOST']}";
                $pathArray = explode('/', $_SERVER['PHP_SELF']);
                array_pop($pathArray);
                array_pop($pathArray);
                $path = implode('/', $pathArray);
                $callbackUrl = $this->getUrl('ipqualityscore/index/token');
                $callbackUrl = str_replace($mainPath, '', $callbackUrl);
                $url = "https://www.ipqualityscore.com/oauth/magentov2/login?domain={$domain}&success_path=" . urlencode($callbackUrl) . "&failure_path=" . urlencode($returnUrl) . "&protocol={$protocol}";
                $resultPage->getLayout()->getBlock('ipqualityscore_dashboard')->setAuthUrl($url);
                $resultPage->getLayout()->getBlock('ipqualityscore_dashboard')->setAuthed(false);
            } else {
                if (!$overviewGraphs) {
                    $this->configWriter->save('ipqualityscore/general/auth_token', null, $scope = \Magento\Framework\App\Config\ScopeConfigInterface::SCOPE_TYPE_DEFAULT, $scopeId = 0);
                    $resultPage->getLayout()->getBlock('ipqualityscore_dashboard')->setAuthed(false);
                    $domain = $_SERVER['HTTP_HOST'];
                    $protocol = (isset($_SERVER['HTTPS']) && ($_SERVER['HTTPS'] == 'on')) ? 'https' : 'http';
                    $returnUrl = (isset($_SERVER['HTTPS']) && $_SERVER['HTTPS'] === 'on' ? "https" : "http") . "://{$_SERVER['HTTP_HOST']}{$_SERVER['REQUEST_URI']}";
                    $mainPath = (isset($_SERVER['HTTPS']) && $_SERVER['HTTPS'] === 'on' ? "https" : "http") . "://{$_SERVER['HTTP_HOST']}";
                    $pathArray = explode('/', $_SERVER['PHP_SELF']);
                    array_pop($pathArray);
                    array_pop($pathArray);
                    $path = implode('/', $pathArray);
                    $callbackUrl = $this->getUrl('ipqualityscore/index/token');
                    $callbackUrl = str_replace($mainPath, '', $callbackUrl);
                    $url = "https://www.ipqualityscore.com/oauth/magentov2/login?domain={$domain}&success_path=" . urlencode($callbackUrl) . "&failure_path=" . urlencode($returnUrl) . "&protocol={$protocol}";
                    $resultPage->getLayout()->getBlock('ipqualityscore_dashboard')->setAuthUrl($url);
                    $resultPage->getLayout()->getBlock('ipqualityscore_dashboard')->setAuthed(false);
                } else {
                    $resultPage->getLayout()->getBlock('ipqualityscore_dashboard')->setAuthed(true);
                    $resultPage->getLayout()->getBlock('ipqualityscore_dashboard')->setOverviewGraphs($overviewGraphs);
                }
            }
            echo "<script src = 'https://cdn.jsdelivr.net/npm/vue@2/dist/vue.js'></script>";
            return $resultPage;
        } catch (Exception $e) {
            echo $e->getMessage();
        }
    }
}
